/*#############################################################
File Name       : ex10_button_count_function.c
Author          : Grant Phillips
Date Modified   : 06/09/2013
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F0-Discovery

Description     : Same as ex9_button_count_debounce.c, but uses
                  a user defined function is_button_pressed() to
                  debounce the input pushbutton's state.	       

Requirements    : * STM32F0-Discovery Board
              
Circuit         : * 8 LEDs connected to PC7 - PC0
									* a pushbutton connected to PB8 with a 
                    pullup resitor

See the STM32F0-Discovery User Manual (UM1525) for the block 
diagram of the STM32F051R8T6 processor (p13), a summary of
the GPIO connections (p20-26) and the schematic diagram (p37-39)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "main.h"																								//main library to include for device drivers, peripheral drivers, etc.

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/
unsigned char is_button_pressed(void);													//needs to be declared before is_button_pressed() can be used

/* #global variables -----------------------------------------*/



// Unused global variables that have to be included to ensure correct compiling */
// ###### DO NOT CHANGE ######
// ===============================================================================
__IO uint32_t TimingDelay = 0;																	//used with the Delay function
__IO uint8_t DataReady = 0;
__IO uint32_t USBConnectTimeOut = 100;
__IO uint32_t UserButtonPressed = 0;
__IO uint8_t PrevXferComplete = 1;
// ===============================================================================



int main(void)
{
	GPIO_InitTypeDef        GPIO_InitStructure;										//structure used for setting up a GPIO port
	RCC_ClocksTypeDef 			RCC_Clocks;														//structure used for setting up the SysTick Interrupt
	
	unsigned int count=0;            //integer variable to store count
	
	/* GPIOB and GPIOC Periph clock enable */
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOC | RCC_AHBPeriph_GPIOB, ENABLE);
  
  /* Configure PC7 - PC0 in output pushpull mode; see stm32f30x_gpio.c and stm32f30x_gpio.h for other definitions*/
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_7 | GPIO_Pin_6 | GPIO_Pin_5 | GPIO_Pin_4 | GPIO_Pin_3 | GPIO_Pin_2 | GPIO_Pin_1 | GPIO_Pin_0;	//which pins to setup, seperated by |
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;									
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;								
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;							
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;							
  GPIO_Init(GPIOC, &GPIO_InitStructure);												
  	
	/* Configure PB8 in input mode; see stm32f30x_gpio.c and stm32f30x_gpio.h for other definitions*/
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_8;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;									
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;							
  GPIO_Init(GPIOB, &GPIO_InitStructure);
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										
	
	GPIO_Write(GPIOC, 0x00);        //clear the LEDs
	
	/* Main program loop */
  while (1)
  {
		if(is_button_pressed() == 1)  				//is the pushbutton pressed      
    {
      while(is_button_pressed() == 1); 		//wait for the pushbutton to be released
      count = count + 1;         					//increment count
      GPIO_Write(GPIOC, count);  					//display count on LEDs
    }  											
  }	
}


//the function will return a 1 if the button is pressed (allowing for contact bounce)
//and 0 if the button is not pressed
unsigned char is_button_pressed(void)
{
	if(GPIO_ReadInputDataBit(GPIOB, GPIO_Pin_8) == 0)		//is the pushbutton pressed (input = 0)      
  {
    Delay(10);             														//wait 10ms for debounce
    if(GPIO_ReadInputDataBit(GPIOB, GPIO_Pin_8) == 0) //is the pushbutton still presed? otherwise 
    {                             										//it was due to contact bounce and must be ignored
			return(1);                 	//button is pressed
    }
  }
  else
  {
		return(0);                    //button is not pressed
  }   
}


// -------------------------------------------------------------------------------

// Function to insert a timing delay of nTime
// ###### DO NOT CHANGE ######
void Delay(__IO uint32_t nTime)
{
  TimingDelay = nTime;

  while(TimingDelay != 0);
}

// Function to Decrement the TimingDelay variable.
// ###### DO NOT CHANGE ######
void TimingDelay_Decrement(void)
{
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

// Unused functions that have to be included to ensure correct compiling
// ###### DO NOT CHANGE ######
// =======================================================================
uint32_t L3GD20_TIMEOUT_UserCallback(void)
{
  return 0;
}

uint32_t LSM303DLHC_TIMEOUT_UserCallback(void)
{
  return 0;
}
// =======================================================================



