/*#############################################################
File Name       : ex2b_flash_one_led.c
Author          : Grant Phillips
Date Modified   : 06/09/2013
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F0-Discovery

Description     : Example program that turns on an LED for 
                  400ms, then off for 400ms, repeatedly.        

Requirements    : * STM32F0-Discovery Board
              
Circuit         : * 1 LED connected to PC8 (LD4 (BLUE) ON 
										STM32F0-DISCOVERY BOARD)

See the STM32F0-Discovery User Manual (UM1525) for the block 
diagram of the STM32F051R8T6 processor (p13), a summary of
the GPIO connections (p20-26) and the schematic diagram (p37-39)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "main.h"																								//main library to include for device drivers, peripheral drivers, etc.

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/



// Unused global variables that have to be included to ensure correct compiling */
// ###### DO NOT CHANGE ######
// ===============================================================================
__IO uint32_t TimingDelay = 0;																	//used with the Delay function
__IO uint8_t DataReady = 0;
__IO uint32_t USBConnectTimeOut = 100;
__IO uint32_t UserButtonPressed = 0;
__IO uint8_t PrevXferComplete = 1;
// ===============================================================================



int main(void)
{
	GPIO_InitTypeDef        GPIO_InitStructure;										//structure used for setting up a GPIO port
	RCC_ClocksTypeDef 			RCC_Clocks;														//structure used for setting up the SysTick Interrupt
	
	/* GPIOC Periph clock enable */
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOC, ENABLE);		//enable the AHB bus to use GPIOE
  
	/* Configure PC8 in output pushpull mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_8;											//which pins to setup, seperated by |
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;									//setup for output mode
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;								//push-pull mode; also available is GPIO_OType_OD (open drain)
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;							//update speed is 50Mhz; also available is GPIO_Speed_10MHz and GPIO_Speed_2MHz
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;							//output not pulled up or down
  GPIO_Init(GPIOC, &GPIO_InitStructure);												//initialize GPIOE with the above structure
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										//will end up in this infinite loop if there was an error with Systick_Config
	
	/* Main program loop */
  while (1)
  {
		GPIO_WriteBit(GPIOC, GPIO_Pin_8, Bit_SET);									//set bit 8 on GPIOC
		Delay(400);																									//wait 400ms	
		GPIO_WriteBit(GPIOC, GPIO_Pin_8, Bit_RESET);								//clear bit 8 on GPIOC
		Delay(400);																									//wait 400ms	
  }	
}

// -------------------------------------------------------------------------------

// Function to insert a timing delay of nTime
// ###### DO NOT CHANGE ######
void Delay(__IO uint32_t nTime)
{
  TimingDelay = nTime;

  while(TimingDelay != 0);
}

// Function to Decrement the TimingDelay variable.
// ###### DO NOT CHANGE ######
void TimingDelay_Decrement(void)
{
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

// Unused functions that have to be included to ensure correct compiling
// ###### DO NOT CHANGE ######
// =======================================================================
uint32_t L3GD20_TIMEOUT_UserCallback(void)
{
  return 0;
}

uint32_t LSM303DLHC_TIMEOUT_UserCallback(void)
{
  return 0;
}
// =======================================================================


