/*#############################################################
File Name       : ex3_sw_leds.c
Author          : Grant Phillips
Date Modified   : 06/09/2013
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F0-Discovery

Description     : Reads the value of 8 switches and displays 
                  this value on 8 LEDs        

Requirements    : * STM32F0-Discovery Board
              
Circuit         : * 8 LEDs connected to PC7 - PC0
									* 8 switches connected to PB8 - PB15 with
                    pullup resitors

See the STM32F0-Discovery User Manual (UM1525) for the block 
diagram of the STM32F051R8T6 processor (p13), a summary of
the GPIO connections (p20-26) and the schematic diagram (p37-39)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "main.h"																								//main library to include for device drivers, peripheral drivers, etc.

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/



// Unused global variables that have to be included to ensure correct compiling */
// ###### DO NOT CHANGE ######
// ===============================================================================
__IO uint32_t TimingDelay = 0;																	//used with the Delay function
__IO uint8_t DataReady = 0;
__IO uint32_t USBConnectTimeOut = 100;
__IO uint32_t UserButtonPressed = 0;
__IO uint8_t PrevXferComplete = 1;
// ===============================================================================



int main(void)
{
	GPIO_InitTypeDef        GPIO_InitStructure;										//structure used for setting up a GPIO port
	RCC_ClocksTypeDef 			RCC_Clocks;														//structure used for setting up the SysTick Interrupt
	
	unsigned int inval;
	
	/* GPIOB and GPIOC Periph clock enable */
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOC | RCC_AHBPeriph_GPIOB, ENABLE);		//enable the AHB bus to use GPIOC and GPIOB
  
  /* Configure PC7 - PC0 in output pushpull mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_7 | GPIO_Pin_6 | GPIO_Pin_5 | GPIO_Pin_4 | GPIO_Pin_3 | GPIO_Pin_2 | GPIO_Pin_1 | GPIO_Pin_0;	//which pins to setup, seperated by |
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;									//setup for output mode
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;								//push-pull mode; also available is GPIO_OType_OD (open drain)
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;							//update speed is 50Mhz; also available is GPIO_Speed_10MHz and GPIO_Speed_2MHz
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;							//output not pulled up or down
  GPIO_Init(GPIOC, &GPIO_InitStructure);												//initialize GPIOC with the above structure
  
	/* Configure PB15 - PB8 in input mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_15 | GPIO_Pin_14 | 
																GPIO_Pin_13 | GPIO_Pin_12 | 
																GPIO_Pin_11 | GPIO_Pin_10 | 
																GPIO_Pin_9 | GPIO_Pin_8;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;									//setup for input mode
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;							//input not pulled up or down
  GPIO_Init(GPIOB, &GPIO_InitStructure);												//initialize GPIOB with the above structure
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										//will end up in this infinite loop if there was an error with Systick_Config
	
	/* Main program loop */
  while (1)
  {
		/* Read the input port and store the value in inval, then shift the result 8 spaces
		to the right so that it can be written to PC7 - PC0.  E.g. if all the switches were
		OFF, then the inval = 0xff00 (inverse logic due to pullup resistors), after the 
		shift it is 0x00ff and can be written to PC7 - PC0 */
		inval = GPIO_ReadInputData(GPIOB) >> 8;		
		
		/* Write the input value to PC7 - PC0 */
		GPIO_Write(GPIOC, inval);																	
  }	
}

// -------------------------------------------------------------------------------

// Function to insert a timing delay of nTime
// ###### DO NOT CHANGE ######
void Delay(__IO uint32_t nTime)
{
  TimingDelay = nTime;

  while(TimingDelay != 0);
}

// Function to Decrement the TimingDelay variable.
// ###### DO NOT CHANGE ######
void TimingDelay_Decrement(void)
{
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

// Unused functions that have to be included to ensure correct compiling
// ###### DO NOT CHANGE ######
// =======================================================================
uint32_t L3GD20_TIMEOUT_UserCallback(void)
{
  return 0;
}

uint32_t LSM303DLHC_TIMEOUT_UserCallback(void)
{
  return 0;
}
// =======================================================================



