/*#############################################################
File Name       : ex4c_button_led.c
Author          : Grant Phillips
Date Modified   : 06/09/2013
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F0-Discovery

Description     : Reads the value of button and then turns an
                  LED on when the button is on otherwise the
                  LED is turned off.          
									This example makes use of the predefined
									functions STM_EVAL_LEDInit(), STM_EVAL_LEDOff(),
									and STM_EVAL_LEDOn(), STM_EVAL_PBInit(), and
									STM_EVAL_PBGetState() which are to be used
									with LD4 (BLUE) and the USER button on the 
									STM32F0-Discovery board.	       

Requirements    : * STM32F0-Discovery Board
              
Circuit         : * a pushbutton connected to PA0 (USER BUTTON
										STM32F0-DISCOVERY BOARD)
                  * 1 LED connected to PC8 (LD4 ON 
										STM32F0-DISCOVERY BOARD)

See the STM32F0-Discovery User Manual (UM1525) for the block 
diagram of the STM32F051R8T6 processor (p13), a summary of
the GPIO connections (p20-26) and the schematic diagram (p37-39)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "main.h"																								//main library to include for device drivers, peripheral drivers, etc.

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/



// Unused global variables that have to be included to ensure correct compiling */
// ###### DO NOT CHANGE ######
// ===============================================================================
__IO uint32_t TimingDelay = 0;																	//used with the Delay function
__IO uint8_t DataReady = 0;
__IO uint32_t USBConnectTimeOut = 100;
__IO uint32_t UserButtonPressed = 0;
__IO uint8_t PrevXferComplete = 1;
// ===============================================================================



int main(void)
{
	RCC_ClocksTypeDef 			RCC_Clocks;														//structure used for setting up the SysTick Interrupt
	
	unsigned int inval;

	/* Initialize LED4 available on STM32F0-Discovery board */
  STM_EVAL_LEDInit(LED4);											
  
	/* Configure the USER button on STM32F0-Discovery as simple IO */
  STM_EVAL_PBInit(BUTTON_USER, BUTTON_MODE_GPIO); 
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										
	
	/* Main program loop */
  while (1)
  {
		/* Read the value on input pin PA0 */
		inval = STM_EVAL_PBGetState(BUTTON_USER);	
		
		/* Write the input value to PC8 */
		if (inval == 1)
			STM_EVAL_LEDOn(LED4);		
		else
			STM_EVAL_LEDOff(LED4);
  }	
}

// -------------------------------------------------------------------------------

// Function to insert a timing delay of nTime
// ###### DO NOT CHANGE ######
void Delay(__IO uint32_t nTime)
{
  TimingDelay = nTime;

  while(TimingDelay != 0);
}

// Function to Decrement the TimingDelay variable.
// ###### DO NOT CHANGE ######
void TimingDelay_Decrement(void)
{
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

// Unused functions that have to be included to ensure correct compiling
// ###### DO NOT CHANGE ######
// =======================================================================
uint32_t L3GD20_TIMEOUT_UserCallback(void)
{
  return 0;
}

uint32_t LSM303DLHC_TIMEOUT_UserCallback(void)
{
  return 0;
}
// =======================================================================



