/*#############################################################
File Name       : ex6_sw_leds_truth.c
Author          : Grant Phillips
Date Modified   : 06/09/2013
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F0-Discovery

Description     : Reads the value of 3 switches and then 
                  controls the output of 8 LEDs as follows:
                  SW2 SW3 SW0 LEDs (0=OFF, 1=ON)
                   0   0   0  00000000
                   0   0   1  00001111
                   0   1   0  11110000
                   0   1   1  11111111
                   1   0   0  10101010
                   1   0   1  10101010
                   1   1   0  10101010
                   1   1   1  10101010   	       

Requirements    : * STM32F0-Discovery Board
              
Circuit         : * 8 LEDs connected to PC7 - PC0
									* 3 switches connected to PB15(SW2), PB14(SW1) 
									  and PB13(SW0) with pullup resitors

See the STM32F0-Discovery User Manual (UM1525) for the block 
diagram of the STM32F051R8T6 processor (p13), a summary of
the GPIO connections (p20-26) and the schematic diagram (p37-39)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "main.h"																								//main library to include for device drivers, peripheral drivers, etc.

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/



// Unused global variables that have to be included to ensure correct compiling */
// ###### DO NOT CHANGE ######
// ===============================================================================
__IO uint32_t TimingDelay = 0;																	//used with the Delay function
__IO uint8_t DataReady = 0;
__IO uint32_t USBConnectTimeOut = 100;
__IO uint32_t UserButtonPressed = 0;
__IO uint8_t PrevXferComplete = 1;
// ===============================================================================



int main(void)
{
	GPIO_InitTypeDef        GPIO_InitStructure;										//structure used for setting up a GPIO port
	RCC_ClocksTypeDef 			RCC_Clocks;														//structure used for setting up the SysTick Interrupt
	unsigned int SW2, SW1, SW0;      															//integer variables to store the input 
																																//values from the 3 switches
	
	/* GPIOB and GPIOC Periph clock enable */
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOC | RCC_AHBPeriph_GPIOB, ENABLE);
  
  /* Configure PC7 - PC0 in output pushpull mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_7 | GPIO_Pin_6 | GPIO_Pin_5 | GPIO_Pin_4 | GPIO_Pin_3 | GPIO_Pin_2 | GPIO_Pin_1 | GPIO_Pin_0;	//which pins to setup, seperated by |
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;									
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;								
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;							
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;							
  GPIO_Init(GPIOC, &GPIO_InitStructure);												
  
	/* Configure PB15 - PB13 in input mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_15 | 
																GPIO_Pin_14 | 
																GPIO_Pin_13;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;									
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
  GPIO_Init(GPIOB, &GPIO_InitStructure);												
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										
	
	/* Main program loop */
  while (1)
  {
		SW0 = GPIO_ReadInputDataBit(GPIOB, GPIO_Pin_13);          	//read the input value for SW0
    SW1 = GPIO_ReadInputDataBit(GPIOB, GPIO_Pin_14);         		//read the input value for SW1
    SW2 = GPIO_ReadInputDataBit(GPIOB, GPIO_Pin_15);          	//read the input value for SW2

      //when a switch is on the input = 0 and if it is off then the input = 1
      //this means in this example it is opposite to the truth table, so you can
      //do the following:
      //1) invert the input value as you read them
      //    SW0 = 1 - GPIO_ReadInputDataBit(GPIOB, GPIO_Pin_13);   //invert the input value for SW0
      //    SW1 = 1 - GPIO_ReadInputDataBit(GPIOB, GPIO_Pin_14);   //invert the input value for SW1
      //    SW2 = 1 - GPIO_ReadInputDataBit(GPIOB, GPIO_Pin_15);   //invert the input value for SW1
      //2) invert the variable after you have read them
      //    SW0 = 1 - SW0;             //invert variables
      //    SW1 = 1 - SW1;
      //    SW2 = 1 - SW2;
      //3) change the truth table to allow for the active-low inputs
      //        SW2 SW3 SW0 LEDs (0=OFF, 1=ON)
      //         1   1   1  00000000
      //         1   1   0  00001111
      //         1   0   1  11110000
      //         1   0   0  11111111
      //         0   1   1  10101010
      //         0   1   0  10101010
      //         0   0   1  10101010
      //         0   0   0  10101010
      //I will use option 2 (there are no real advantages for using this option)
   
    SW0 = 1 - SW0;         //invert variables (1 becomes 0, 0 becomes 1)
    SW1 = 1 - SW1;
    SW2 = 1 - SW2;
      
      //use one of the following options to apply the truth table:
      /* 1) */

    if((SW2==0) && (SW1==0) && (SW0==0))
       GPIO_Write(GPIOC, 0x00);        // or GPIO_Write(GPIOC, 0); for decimal
    else if((SW2==0) && (SW1==0) && (SW0==1))
       GPIO_Write(GPIOC, 0x0f);        // or GPIO_Write(GPIOC, 15); for decimal
    else if((SW2==0) && (SW1==1) && (SW0==0))
       GPIO_Write(GPIOC, 0xf0);        // or GPIO_Write(GPIOC, 240); for decimal
    else if((SW2==0) && (SW1==1) && (SW0==1))
       GPIO_Write(GPIOC, 0xff);        // or GPIO_Write(GPIOC, 255); for decimal
    else                    	// any other combination of inputs will go to this else statement
       GPIO_Write(GPIOC, 0xaa);        // or GPIO_Write(GPIOC, 170); for decimal
      

      /* or 2)
      declare another variable at the top:
      unsigned int val; 

      val = (SW2 * 4) + (SW1 * 2) + SW0;   //create a integer value from the single inputs
      switch(val)
      {
         case 0:   GPIO_Write(GPIOC, 0x00);
               break;
         case 1:   GPIO_Write(GPIOC, 0x0f);
               break;
         case 2:   GPIO_Write(GPIOC, 0xf0);
               break;
         case 3:   GPIO_Write(GPIOC, 0xff);
               break;
         default: GPIO_Write(GPIOC, 0xaa);
      }
      */															
  }	
}

// -------------------------------------------------------------------------------

// Function to insert a timing delay of nTime
// ###### DO NOT CHANGE ######
void Delay(__IO uint32_t nTime)
{
  TimingDelay = nTime;

  while(TimingDelay != 0);
}

// Function to Decrement the TimingDelay variable.
// ###### DO NOT CHANGE ######
void TimingDelay_Decrement(void)
{
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

// Unused functions that have to be included to ensure correct compiling
// ###### DO NOT CHANGE ######
// =======================================================================
uint32_t L3GD20_TIMEOUT_UserCallback(void)
{
  return 0;
}

uint32_t LSM303DLHC_TIMEOUT_UserCallback(void)
{
  return 0;
}
// =======================================================================



