/*#############################################################
File Name       : ex7_led_count.c
Author          : Grant Phillips
Date Modified   : 06/09/2013
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F0-Discovery

Description     : Increments a counter from 0 to 255 repeatedly
                  in 200ms delays and display the count value
                  on 8 LEDs  	       

Requirements    : * STM32F0-Discovery Board
              
Circuit         : * 8 LEDs connected to PC7 - PC0

See the STM32F0-Discovery User Manual (UM1525) for the block 
diagram of the STM32F051R8T6 processor (p13), a summary of
the GPIO connections (p20-26) and the schematic diagram (p37-39)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "main.h"																								//main library to include for device drivers, peripheral drivers, etc.

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/



// Unused global variables that have to be included to ensure correct compiling */
// ###### DO NOT CHANGE ######
// ===============================================================================
__IO uint32_t TimingDelay = 0;																	//used with the Delay function
__IO uint8_t DataReady = 0;
__IO uint32_t USBConnectTimeOut = 100;
__IO uint32_t UserButtonPressed = 0;
__IO uint8_t PrevXferComplete = 1;
// ===============================================================================



int main(void)
{
	GPIO_InitTypeDef        GPIO_InitStructure;										//structure used for setting up a GPIO port
	RCC_ClocksTypeDef 			RCC_Clocks;														//structure used for setting up the SysTick Interrupt
	
	unsigned int count=0;            //integer variable to store count
	
	/* GPIOC Periph clock enable */
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOC, ENABLE);
  
  /* Configure PC7 - PC0 in output pushpull mode; see stm32f30x_gpio.c and stm32f30x_gpio.h for other definitions*/
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_7 | GPIO_Pin_6 | GPIO_Pin_5 | GPIO_Pin_4 | GPIO_Pin_3 | GPIO_Pin_2 | GPIO_Pin_1 | GPIO_Pin_0;	//which pins to setup, seperated by |
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;									
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;								
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;							
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;							
  GPIO_Init(GPIOC, &GPIO_InitStructure);												
  	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										
	
	/* Main program loop */
  while (1)
  {
    GPIO_Write(GPIOC, count);     //display count on LEDs
    count = count + 1;            //increment count
    if(count == 256)
       count = 0;                 //reset counter if it reaches 256 *** see writeup below
    Delay(200);            				//delay 200ms													
  }	
}

/*
count was delcared as an unsigned integer variable, which means it is a 
16-bit variable with no sign bit and can therefore hold a value of 0 to
65535.  

If it was declared as
int count;
it would still be a 16-bit variable, but with a sign bit and can therefore
hold a value of -32768 to +32767.

To create a 8-bit variable (which uses less memory), we can declare it as
char count;            (signed 8-bit variable; -128 to 127)
unsigned char count;   (unsigned 8-bit variable; 0 to 255)

So if count was delcared as 
unsigned char count;
then the 
if(count == 256)
statement was not necessary, because the counter would have simply "rolled
over" from 255 to 0 seeing that it can only store 8 bits.
*/


// -------------------------------------------------------------------------------

// Function to insert a timing delay of nTime
// ###### DO NOT CHANGE ######
void Delay(__IO uint32_t nTime)
{
  TimingDelay = nTime;

  while(TimingDelay != 0);
}

// Function to Decrement the TimingDelay variable.
// ###### DO NOT CHANGE ######
void TimingDelay_Decrement(void)
{
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

// Unused functions that have to be included to ensure correct compiling
// ###### DO NOT CHANGE ######
// =======================================================================
uint32_t L3GD20_TIMEOUT_UserCallback(void)
{
  return 0;
}

uint32_t LSM303DLHC_TIMEOUT_UserCallback(void)
{
  return 0;
}
// =======================================================================



